Module bytecode

Module bytecode 

Module that contains the bytecode struct with all variants supported by Ethereum mainnet.

Those are:

  • Legacy bytecode with jump table analysis
  • EIP-7702 bytecode, introduced in Prague and contains address to delegated account

Structs

Bytecode
Ethereum EVM bytecode.

Enums

BytecodeKind
The kind of bytecode.