pub struct Bytecode(/* private fields */);Expand description
Ethereum EVM bytecode.
Implementations
Sourceimpl Bytecode
impl Bytecode
Sourcepub fn new_legacy(raw: Bytes) -> Self
pub fn new_legacy(raw: Bytes) -> Self
Creates a new legacy Bytecode by analyzing raw bytes.
Sourcepub fn new_raw(bytecode: Bytes) -> Self
pub fn new_raw(bytecode: Bytes) -> Self
Creates a new raw Bytecode.
Panics
Panics if bytecode is in incorrect format. If you want to handle errors use Self::new_raw_checked.
Sourcepub fn new_eip7702(address: Address) -> Self
pub fn new_eip7702(address: Address) -> Self
Sourcepub fn new_raw_checked(bytes: Bytes) -> Result<Self, BytecodeDecodeError>
pub fn new_raw_checked(bytes: Bytes) -> Result<Self, BytecodeDecodeError>
Creates a new raw Bytecode.
Returns an error on incorrect bytecode format.
Sourcepub fn new_eip7702_raw(bytes: Bytes) -> Result<Self, Eip7702DecodeError>
pub fn new_eip7702_raw(bytes: Bytes) -> Result<Self, Eip7702DecodeError>
Creates a new EIP-7702 Bytecode from raw bytes.
Returns an error if the bytes are not valid EIP-7702 bytecode.
Sourcepub fn new_analyzed(
bytecode: Bytes,
original_len: usize,
jump_table: JumpTable,
) -> Self
pub fn new_analyzed( bytecode: Bytes, original_len: usize, jump_table: JumpTable, ) -> Self
Create new checked bytecode from pre-analyzed components.
Panics
- If
original_lenis greater thanbytecode.len() - If jump table length is less than
original_len - If bytecode is empty
Sourcepub fn kind(&self) -> BytecodeKind
pub fn kind(&self) -> BytecodeKind
Returns the kind of bytecode.
Sourcepub fn is_eip7702(&self) -> bool
pub fn is_eip7702(&self) -> bool
Returns true if bytecode is EIP-7702.
Sourcepub fn eip7702_address(&self) -> Option<Address>
pub fn eip7702_address(&self) -> Option<Address>
Returns the EIP-7702 delegated address if this is EIP-7702 bytecode.
Sourcepub fn legacy_jump_table(&self) -> Option<&JumpTable>
pub fn legacy_jump_table(&self) -> Option<&JumpTable>
Returns jump table if bytecode is legacy analyzed.
Sourcepub fn bytecode(&self) -> &Bytes
pub fn bytecode(&self) -> &Bytes
Returns a reference to the bytecode bytes.
For legacy bytecode, this includes padding. For EIP-7702, this is the raw bytes.
Sourcepub fn bytecode_ptr(&self) -> *const u8
pub fn bytecode_ptr(&self) -> *const u8
Pointer to the bytecode bytes.
Sourcepub fn bytes_slice(&self) -> &[u8] ⓘ
pub fn bytes_slice(&self) -> &[u8] ⓘ
Returns the bytecode as a slice.
Sourcepub fn original_bytes(&self) -> Bytes
pub fn original_bytes(&self) -> Bytes
Returns the original bytecode without padding.
Sourcepub fn original_byte_slice(&self) -> &[u8] ⓘ
pub fn original_byte_slice(&self) -> &[u8] ⓘ
Returns the original bytecode as a byte slice without padding.
Sourcepub fn iter_opcodes(&self) -> BytecodeIterator<'_> ⓘ
pub fn iter_opcodes(&self) -> BytecodeIterator<'_> ⓘ
Returns an iterator over the opcodes in this bytecode, skipping immediates.